==> dokuwiki-2013.05.10.tgz: dokuwiki/inc/lang/mg/lang.php <==
<?php
/**
 * mg language file
 */
$lang['encoding']   = 'utf-8';
$lang['direction']  = 'ltr';

$lang['btn_edit']   = 'Hanova ny pejy';
$lang['btn_source'] = 'Asehoy ny source';
$lang['btn_show']   = 'Asehoy ny pejy';
$lang['btn_create'] = 'Amboary ity pejy';
$lang['btn_search'] = 'Hikaroka';
$lang['btn_save']   = 'Raketo';
$lang['btn_preview']= 'Topi-maso';
$lang['btn_top']    = 'Ho ery ambony';
$lang['btn_newer']  = '<< taloha kokoa';
$lang['btn_older']  = 'taoriana kokoa >>';
$lang['btn_revs']   = 'Kinova taloha';
$lang['btn_recent'] = 'Fiovana farany';
$lang['btn_upload'] = 'Alefaso';
$lang['btn_cancel'] = 'Aoka ihany';
$lang['btn_index']  = 'Index';
$lang['btn_secedit']= 'Edit';
$lang['btn_login']  = 'Hiditra';
$lang['btn_logout'] = 'Hivoaka';
$lang['btn_admin']  = 'Admin';
$lang['btn_update'] = 'Update';
$lang['btn_delete'] = 'Fafao';
$lang['btn_back']   = 'Miverina';
$lang['btn_backtomedia'] = 'Fitsongana fichier Media';
$lang['btn_register'] = 'Hisoratra';

$lang['loggedinas'] = 'Anaranao:';
$lang['user']       = 'Anarana';
$lang['pass']       = 'Alahidy';
$lang['passchk']    = 'Ataovy indray';
$lang['remember']   = 'Tsarovy';
$lang['fullname']   = 'Anarana feno';
$lang['email']      = 'Imailaka';
$lang['badlogin']   = 'Miala tsiny fa misy diso ny anarana na ny alahidy.';

$lang['regmissing'] = 'Tsy maintsy fenoina ny saha rehetra.';
$lang['reguexists'] = 'Indrisy fa efa nisy namandrika io anarana io.';
$lang['regsuccess'] = 'Voaforona ny kaontinao, halefa any imailaka ny alahidy.';
$lang['regsuccess2']= 'Voaforona ilay kaonty.';
$lang['regmailfail']= 'Ohatra ny nisy olana ny nandefasana imailaka. Miangavy anao hilaza ny Admin!';
$lang['regbadmail'] = 'Toa tsy mandeha ny imailaka nomenao - Raha heverinao fa erreur io dia ilazao ny admin';
$lang['regbadpass'] = 'Tsy mitovy ny alahidy roa nomenao, avereno indray.';
$lang['regpwmail']  = 'Ny alahidy Wiki-nao';
$lang['reghere']    = 'Mbola tsy manana kaonty ianao? Manaova vaovao';

$lang['txt_upload']   = 'Misafidiana rakitra halefa';
$lang['txt_filename'] = 'Ampidiro ny anaran\'ny wiki (tsy voatery)';
$lang['txt_overwrt']  = 'Fafana izay rakitra efa misy?';
$lang['lockedby']     = 'Mbola voahidin\'i';
$lang['lockexpire']   = 'Afaka ny hidy amin\'ny';
$lang['js']['willexpire']   = 'Efa ho lany fotoana afaka iray minitra ny hidy ahafahanao manova ny pejy.\nMba hialana amin\'ny conflit dia ampiasao ny bokotra topi-maso hamerenana ny timer-n\'ny hidy.';

$lang['js']['notsavedyet'] = 'Misy fiovana tsy voarakitra, ho very izany ireo.\nAzo antoka fa hotohizana?';
$lang['rssfailed']   = 'An error occured while fetching this feed: ';
$lang['nothingfound']= 'Tsy nahitana n\'inon\'inona.';

$lang['mediaselect'] = 'Safidy rakitra Media';
$lang['fileupload']  = 'Fandefasana rakitra Media';
$lang['uploadsucc']  = 'Voalefa soa aman-tsara';
$lang['uploadfail']  = 'Tsy lasa ilay izy. Mety tsy fananana alalana?';
$lang['uploadwrong'] = 'Nolavina ny lefa. Voarara io extension-na rakitra io!';
$lang['uploadexist'] = 'Efa misy ilay rakitra. Tsy nisy inona natao.';
$lang['deletesucc']  = 'Voafafa ny rakitra "%s" .';
$lang['deletefail']  = 'Tsy afaka nofafana ny "%s" - Hamarino ny alalana.';
$lang['mediainuse']  = 'Tsy voafafa ny rakitra "%s" - mbola misy mampiasa io.';
$lang['namespaces']  = 'Namespaces';
$lang['mediafiles']  = 'Rakitra misy amin\'ny';

$lang['reference']   = 'References for';
$lang['ref_inuse']   = 'Tsy afaka fafana io rakitra io, satria mbola ampiasain\'ireto pejy ireto:';
$lang['ref_hidden']  = 'Misy references  vitsivitsy amina pejy tsy anananao alalana hamaky';

$lang['hits']       = 'Hits';
$lang['quickhits']  = 'Anaram-pejy mifanaraka';
$lang['toc']        = 'Fizahan-takila';
$lang['current']    = 'current';
$lang['yours']      = 'Kinova-nao';
$lang['diff']       = 'Asehoy ny tsy fitoviana amin\'ny kinova amin\'izao';
$lang['line']       = 'Andalana';
$lang['breadcrumb'] = 'Taiza ianao';
$lang['lastmod']    = 'Novaina farany:';
$lang['by']         = '/';
$lang['deleted']    = 'voafafa';
$lang['created']    = 'Voamboatra';
$lang['restored']   = 'Naverina tamin\'ny kinova taloha (%s)';
$lang['summary']    = 'Fanovana teo';

$lang['mail_newpage'] = 'pejy niampy:';
$lang['mail_changed'] = 'pejy niova:';

$lang['js']['nosmblinks'] = "rohy mankamin\'ny fizarana Windows dia amin\'ny Microsoft Internet Explorer ihany no miasa.\nAzo atao ihany anefa ny manao dika-petaka ny rohy.";

$lang['qb_bold']    = 'Matavy';
$lang['qb_italic']  = 'Mandry';
$lang['qb_underl']  = 'Voatsipika';
$lang['qb_code']    = 'Code programa';
$lang['qb_strike']  = 'Disoina';
$lang['qb_h1']      = 'Lohateny laharana 1';
$lang['qb_h2']      = 'Lohateny laharana 2';
$lang['qb_h3']      = 'Lohateny laharana 3';
$lang['qb_h4']      = 'Lohateny laharana 4';
$lang['qb_h5']      = 'Lohateny laharana 5';
$lang['qb_link']    = 'Rohy ato anatiny';
$lang['qb_extlink'] = 'Rohy mivoaka';
$lang['qb_hr']      = 'Tsipika marindrano';
$lang['qb_ol']      = 'Tanisa milahatra';
$lang['qb_ul']      = 'Tanisa tsy milahatra';
$lang['qb_media']   = 'Hanampy sary na rakitra hafa';
$lang['qb_sig']     = 'Manisy sonia';

$lang['js']['del_confirm']= 'Hofafana ilay andalana?';

$lang['admin_acl']  = 'Fitantanana ACL (Access Control List)...';
$lang['admin_register']= 'Ampio mpampiasa vaovao...';

$lang['acl_group']  = 'Vondrona';
$lang['acl_user']   = 'Mpampiasa';
$lang['acl_perms']  = 'Alalana @';
$lang['page']       = 'Pejy';
$lang['namespace']  = 'Namespace';

$lang['acl_perm1']  = 'Mamaky';
$lang['acl_perm2']  = 'Manova';
$lang['acl_perm4']  = 'Manamboatra';
$lang['acl_perm8']  = 'Mandefa rakitra';
$lang['acl_perm16'] = 'Mamafa';
$lang['acl_new']    = 'Ampio andalana vaovao';

//Setup VIM: ex: et ts=2 :

==> dokuwiki-2015.08.10a.tgz: dokuwiki/inc/lang/mg/lang.php <==
<?php
/**
 * mg language file
 */
$lang['encoding']   = 'utf-8';
$lang['direction']  = 'ltr';

$lang['btn_edit']   = 'Hanova ny pejy';
$lang['btn_source'] = 'Asehoy ny source';
$lang['btn_show']   = 'Asehoy ny pejy';
$lang['btn_create'] = 'Amboary ity pejy';
$lang['btn_search'] = 'Hikaroka';
$lang['btn_save']   = 'Raketo';
$lang['btn_preview']= 'Topi-maso';
$lang['btn_top']    = 'Ho ery ambony';
$lang['btn_newer']  = '<< taloha kokoa';
$lang['btn_older']  = 'taoriana kokoa >>';
$lang['btn_revs']   = 'Kinova taloha';
$lang['btn_recent'] = 'Fiovana farany';
$lang['btn_upload'] = 'Alefaso';
$lang['btn_cancel'] = 'Aoka ihany';
$lang['btn_index']  = 'Index';
$lang['btn_secedit']= 'Edit';
$lang['btn_login']  = 'Hiditra';
$lang['btn_logout'] = 'Hivoaka';
$lang['btn_admin']  = 'Admin';
$lang['btn_update'] = 'Update';
$lang['btn_delete'] = 'Fafao';
$lang['btn_back']   = 'Miverina';
$lang['btn_register'] = 'Hisoratra';

$lang['loggedinas'] = 'Anaranao:';
$lang['user']       = 'Anarana';
$lang['pass']       = 'Alahidy';
$lang['passchk']    = 'Ataovy indray';
$lang['remember']   = 'Tsarovy';
$lang['fullname']   = 'Anarana feno';
$lang['email']      = 'Imailaka';
$lang['badlogin']   = 'Miala tsiny fa misy diso ny anarana na ny alahidy.';

$lang['regmissing'] = 'Tsy maintsy fenoina ny saha rehetra.';
$lang['reguexists'] = 'Indrisy fa efa nisy namandrika io anarana io.';
$lang['regsuccess'] = 'Voaforona ny kaontinao, halefa any imailaka ny alahidy.';
$lang['regsuccess2']= 'Voaforona ilay kaonty.';
$lang['regmailfail']= 'Ohatra ny nisy olana ny nandefasana imailaka. Miangavy anao hilaza ny Admin!';
$lang['regbadmail'] = 'Toa tsy mandeha ny imailaka nomenao - Raha heverinao fa erreur io dia ilazao ny admin';
$lang['regbadpass'] = 'Tsy mitovy ny alahidy roa nomenao, avereno indray.';
$lang['regpwmail']  = 'Ny alahidy Wiki-nao';
$lang['reghere']    = 'Mbola tsy manana kaonty ianao? Manaova vaovao';

$lang['txt_upload']   = 'Misafidiana rakitra halefa:';
$lang['txt_filename'] = 'Ampidiro ny anaran\'ny wiki (tsy voatery):';
$lang['txt_overwrt']  = 'Fafana izay rakitra efa misy?';
$lang['lockedby']     = 'Mbola voahidin\'i:';
$lang['lockexpire']   = 'Afaka ny hidy amin\'ny:';
$lang['js']['willexpire']   = 'Efa ho lany fotoana afaka iray minitra ny hidy ahafahanao manova ny pejy.\nMba hialana amin\'ny conflit dia ampiasao ny bokotra topi-maso hamerenana ny timer-n\'ny hidy.';

$lang['js']['notsavedyet'] = 'Misy fiovana tsy voarakitra, ho very izany ireo.\nAzo antoka fa hotohizana?';
$lang['rssfailed']   = 'An error occured while fetching this feed: ';
$lang['nothingfound']= 'Tsy nahitana n\'inon\'inona.';

$lang['mediaselect'] = 'Safidy rakitra Media';
$lang['uploadsucc']  = 'Voalefa soa aman-tsara';
$lang['uploadfail']  = 'Tsy lasa ilay izy. Mety tsy fananana alalana?';
$lang['uploadwrong'] = 'Nolavina ny lefa. Voarara io extension-na rakitra io!';
$lang['uploadexist'] = 'Efa misy ilay rakitra. Tsy nisy inona natao.';
$lang['deletesucc']  = 'Voafafa ny rakitra "%s" .';
$lang['deletefail']  = 'Tsy afaka nofafana ny "%s" - Hamarino ny alalana.';
$lang['mediainuse']  = 'Tsy voafafa ny rakitra "%s" - mbola misy mampiasa io.';
$lang['namespaces']  = 'Namespaces';
$lang['mediafiles']  = 'Rakitra misy amin\'ny';

$lang['reference']   = 'References for';
$lang['ref_inuse']   = 'Tsy afaka fafana io rakitra io, satria mbola ampiasain\'ireto pejy ireto:';
$lang['ref_hidden']  = 'Misy references  vitsivitsy amina pejy tsy anananao alalana hamaky';

$lang['hits']       = 'Hits';
$lang['quickhits']  = 'Anaram-pejy mifanaraka';
$lang['toc']        = 'Fizahan-takila';
$lang['current']    = 'current';
$lang['yours']      = 'Kinova-nao';
$lang['diff']       = 'Asehoy ny tsy fitoviana amin\'ny kinova amin\'izao';
$lang['line']       = 'Andalana';
$lang['breadcrumb'] = 'Taiza ianao:';
$lang['lastmod']    = 'Novaina farany:';
$lang['by']         = '/';
$lang['deleted']    = 'voafafa';
$lang['created']    = 'Voamboatra';
$lang['restored']   = 'Naverina tamin\'ny kinova taloha (%s)';
$lang['summary']    = 'Fanovana teo';

$lang['mail_newpage'] = 'pejy niampy:';
$lang['mail_changed'] = 'pejy niova:';

$lang['js']['nosmblinks'] = "rohy mankamin\'ny fizarana Windows dia amin\'ny Microsoft Internet Explorer ihany no miasa.\nAzo atao ihany anefa ny manao dika-petaka ny rohy.";

$lang['qb_bold']    = 'Matavy';
$lang['qb_italic']  = 'Mandry';
$lang['qb_underl']  = 'Voatsipika';
$lang['qb_code']    = 'Code programa';
$lang['qb_strike']  = 'Disoina';
$lang['qb_h1']      = 'Lohateny laharana 1';
$lang['qb_h2']      = 'Lohateny laharana 2';
$lang['qb_h3']      = 'Lohateny laharana 3';
$lang['qb_h4']      = 'Lohateny laharana 4';
$lang['qb_h5']      = 'Lohateny laharana 5';
$lang['qb_link']    = 'Rohy ato anatiny';
$lang['qb_extlink'] = 'Rohy mivoaka';
$lang['qb_hr']      = 'Tsipika marindrano';
$lang['qb_ol']      = 'Tanisa milahatra';
$lang['qb_ul']      = 'Tanisa tsy milahatra';
$lang['qb_media']   = 'Hanampy sary na rakitra hafa';
$lang['qb_sig']     = 'Manisy sonia';

$lang['js']['del_confirm']= 'Hofafana ilay andalana?';

$lang['searchcreatepage']      = "Raha tsy nahita izay notadiavinao ianao, dia afaka mamorona pejy vaovao avy amin'ny teny nanaovanao fikarohana; Ampiasao ny bokotra ''Hanova ny pejy''.";
//Setup VIM: ex: et ts=2 :
